@@ -38,8 +38,7 @@ def main():
     else:
         urls = sys.argv[1:]
 
-    for url in urls:
-        video_dl(url)
+    return 0 if all(list(map(video_dl, urls))) else 1
 
 def video_dl(url):
     xml = objectify.fromstring(urllib.request.urlopen(XML_API % get_id(url)).read())
@@ -49,7 +48,7 @@ def video_dl(url):
         print("Error retrieving manifest:")
         print("  %s" % status.statuscode.text)
         print("  %s" % status.debuginfo.text)
-        return 2
+        return False
 
     video = xml.video
     title = video.information.title.text
@@ -88,11 +87,10 @@ def video_dl(url):
                 sys.stdout.write(" "*40 + "\r")
                 sys.stdout.write("  %s/%s MB – %0.2f %%\r" % (format_mb(size), format_mb(target_size), round((float(size) / target_size)*100, 2)))
                 sys.stdout.flush()
-
-        break
     
-    print()
-    return 0
+        print()
+        return True
+    return False
 
 if __name__ == "__main__":
     sys.exit(main())
